$wnd.rstudio.runAsyncCallback9("function lZr(a){this.a=a}\nfunction UWr(a){a.K._4b();dNg(a.k.p)}\nfunction SWr(a){lZp(a.k);Rci(a.a,JWr.khc(),'loadhistory')}\nfunction TWr(a){lZp(a.k);Wci(a.a,JWr.ohc(),'.Rhistory',false,'savehistory')}\nfunction hZr(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=QZr(a.a.b.a);vTp(a.a,a.a.a)}switch(a.c){case 1:a.a.a.K.Z4b();break;case 2:a.a.a.K.$4b();break;case 3:SWr(a.a.a);break;case 4:TWr(a.a.a);break;case 5:UWr(a.a.a);break;case 6:a.a.a.K.a5b();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].mn()}}\nvar o1A='Load History',p1A='Save History As';TFd(3925,1,jtA);_.khc=function XXr(){return o1A};_.ohc=function _Xr(){return p1A};TFd(3924,1,jtA);_.khc=function qYr(){return o1A};_.ohc=function uYr(){return p1A};TFd(3923,1,jtA);_.khc=function LYr(){return \"Chargement de l'historique\"};_.ohc=function PYr(){return \"Enregistrer l'historique en tant que\"};TFd(511,1,Wwy);_.kn=function kZr(){hZr((new lZr(this)).a)};TFd(7150,1,uZx,lZr);_.mn=function mZr(){hZr(this.a)};var wxc=Ese(7150);qJx(fm)(9);\n//# sourceURL=rstudio-9.js\n")
