$wnd.rstudio.runAsyncCallback7("function DAs(a){this.a=a}\nfunction Jzs(a,b){this.a=a;this.b=b}\nfunction Fzs(a,b){b==null?b1e(a,Dzs.Djc()):b1e(a,b)}\nfunction Wzs(a,b){yi(a.d,new Nbf(false));Nzs(a.d,b,0)}\nfunction S9l(a,b){Bbm(a,Wzy,'markers_tab_closed',new vL,b)}\nfunction Gzs(a,b){var c,d,e,f,g,h,i;d=a.s;Aae(d.p);for(g=b,h=0,i=g.length;h<i;++h){f=g[h];c=new Jzs(a,f);e=new bId(_Hd(new aId,f).a.a);z7g(d,new Sbe(e,c))}}\nfunction Nzs(a,b,c){var d;Slj(a.b);Fzs(a.c,null);Gzs(a.c,kN(fN(_0,1),$Jx,2,6,[]));if(b.markers){d=b.markers;Wlj(a.b,null,d.base_path,d.markers,c,false);Gzs(a.c,ipf(b.names));Fzs(a.c,d.name)}}\nfunction Vzs(a,b){var c,d,e,f,g;g=b.a.markers_state;if(g.markers){yi(a.d,new Nbf(true));Nzs(a.d,b.a.markers_state,b.a.auto_select);e=g.markers;if(e){d=e.markers;if(d.length>0){f=null;c=b.a.auto_select;c==1?(f=d[0]):c==2&&(f=Alj(d));!!f&&cQi(a.b,def(f.path),bUe(f.line,f.column),false)}}}else{yi(a.d,new Gbf)}}\nfunction zAs(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=MAs(a.a.b.a);vTp(a.a,a.a.a)}switch(a.c){case 1:Uzs(a.a.a);break;case 2:a.a.a.K.Z4b();break;case 3:a.a.a.K.$4b();break;case 4:S9l(a.a.a.c,new XAh);break;case 5:Vzs(a.a.a,a.b[0]);break;case 6:a.a.a.K._4b();break;case 7:a.a.a.K.a5b();break;case 8:Wzs(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].mn()}}\nTFd(8772,1,RLx,Jzs);_.mn=function Kzs(){wE(this.a,this.b)};var bEc=Ese(8772);TFd(433,1,Wwy);_.kn=function CAs(){zAs((new DAs(this)).a)};TFd(7008,1,uZx,DAs);_.mn=function EAs(){zAs(this.a)};var oEc=Ese(7008);qJx(fm)(7);\n//# sourceURL=rstudio-7.js\n")
